==> ddd_2.1.1.orig.tar.gz: ddd-2.1.1.orig/ddd/dbx-lookup.h <==
// $Id: dbx-lookup.h,v 1.5 1997/04/25 06:39:04 zeller Exp $ -*- C++ -*-
// Lookup DBX cache

// Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of the DDD Library.
// 
// The DDD Library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// The DDD Library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Library General Public License for more details.
// 
// You should have received a copy of the GNU Library General Public
// License along with the DDD Library -- see the file COPYING.LIB.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers at `ddd@ips.cs.tu-bs.de'.

#ifndef _DDD_dbx_lookup_h
#define _DDD_dbx_lookup_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Find location of FUNC using DBX
string dbx_lookup(const string& func_name);
void clear_dbx_lookup_cache();

// Find path of source file SOURCE
string dbx_path(const string& source);

// Find line# in listing
int line_of_listing(string& listing);

#endif // _DDD_dbx_lookup_h
// DON'T ADD ANYTHING BEHIND THIS #endif

==> ddd_2.2.3.orig.tar.gz: ddd-2.2.3/ddd/dbx-lookup.h <==
// $Id: dbx-lookup.h,v 1.7 1997/10/26 13:14:37 zeller Exp $ -*- C++ -*-
// Lookup DBX cache

// Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
// Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
// 
// This file is part of the DDD Library.
// 
// The DDD Library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Library General Public
// License as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
// 
// The DDD Library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU Library General Public License for more details.
// 
// You should have received a copy of the GNU Library General Public
// License along with the DDD Library -- see the file COPYING.LIB.
// If not, write to the Free Software Foundation, Inc.,
// 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
// 
// DDD is the data display debugger.
// For details, see the DDD World-Wide-Web page, 
// `http://www.cs.tu-bs.de/softech/ddd/',
// or send a mail to the DDD developers <ddd@ips.cs.tu-bs.de>.

#ifndef _DDD_dbx_lookup_h
#define _DDD_dbx_lookup_h

#ifdef __GNUG__
#pragma interface
#endif

#include "strclass.h"

// Find location of FUNC using DBX
string dbx_lookup(const string& func_name, bool silent = true);
void clear_dbx_lookup_cache();

// Find path of source file SOURCE
string dbx_path(const string& source);

// Find line# in listing
int line_of_listing(string& listing, bool silent = true);

#endif // _DDD_dbx_lookup_h
// DON'T ADD ANYTHING BEHIND THIS #endif
